
# Slot: inherited


true means that the *value* of a slot is inherited by subclasses

URI: [linkml:inherited](https://w3id.org/linkml/inherited)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | Inherited applies to slot values.  Parent *slots* are always inherited by subclasses |

